# GARB - Google Analytics Request Builder

GARB is a small library that provides a comfortable way of building a Request
Body for Google Analytics Reporting API v4.

## Installation

Currently, the only installation method is cloning the repository:

    git clone https://github.com/czuhajster/garb

## License

GARB is licensed under [MIT License](https://github.com/czuhajster/garb/blob/main/LICENSE.md).
